@@ -1,6 +1,8 @@
 #ifndef _LINUX_QUICKCAM_H
 #define _LINUX_QUICKCAM_H
 
+//#define DISABLE_INT_URBS
+
 /*
  * This define change behaviour of the whiteness control.
  *  If defined, whiteness controll will set shutter-value instead.
@@ -110,6 +112,7 @@ struct qc_userlut {
 #include <linux/spinlock.h>
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
+//#define USE_KREF
 #ifdef USE_KREF
 /* This is just a test */
 #include <linux/kref.h>
@@ -330,6 +333,8 @@ static inline struct urb *qc_usb_alloc_urb(int packets) { return usb_alloc_urb(p
 		} \
 	} while (0)
 #define POISON(obj)	do { memset(&(obj),POISON_VAL,sizeof(obj)); } while(0)
+#define NOT_POISONED_PTR(obj)   ((obj) && (((unsigned long)(obj) & 0xffffffff) != 0x5b5b5b5b))
+#define POISONED_PTR(obj)   (((obj)==NULL) || (((unsigned long)(obj) & 0xffffffff) == 0x5b5b5b5b))
 
 #else
 
@@ -344,6 +349,8 @@ static inline struct urb *qc_usb_alloc_urb(int packets) { return usb_alloc_urb(p
 #define TEST_BUG_MSG(cond, fmt, args...)
 #define TEST_BUGR_MSG(cond, fmt, args...)
 #define POISON(obj)
+#define NOT_POISONED_PTR(obj)   (obj)
+#define POISONED_PTR(obj)   ((obj)==NULL)
 
 #endif /* DEBUG */
 
@@ -405,7 +412,6 @@ struct qc_int_data {
 	int polling;
 	int abort_polling;
 
-	//volatile int packets;		/* 0=no URBs scheduled, 1=URB scheduled */
 	wait_queue_head_t wq;		/* Woken up when all pending data is sent */
 	IDEBUG_VAR
 };
@@ -567,9 +573,8 @@ struct quickcam {
   
 #ifdef USE_INPUT
 	struct input_dev input;
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
 	char input_physname[64];
-#endif
+	char input_event_path[64];
 #endif
 	int button_status;
 	int button_count;
@@ -577,9 +582,6 @@ struct quickcam {
 	int button_released;
 	int button_pressed_cum;
 	int button_released_cum;
-	int button_pressed_not_handled;
-	int reg1442;
-	int reg144a;
 };
 /* }}} */
 /* {{{ [fold] SECTION: miscelleneous */
